<?php

namespace Drupal\az_blob_fs;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Database\Connection;

/**
 * Class AzBlobFsService.
 */
class AzBlobFsService {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The config factory object.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * Constructs an AzBlobFsService object.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The new database connection object.
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The config factory object.
   */
  public function __construct(Connection $connection, ConfigFactory $config_factory) {
    $this->connection = $connection;
    $this->configFactory = $config_factory;
  }

  /**
   * Get Azure Blob storage container.
   *
   * @return string|null
   */
  public function getBlobContainer(): ?string {
    $container = NULL;
    $config = $this->configFactory->get('az_blob_fs.settings');
    if ($config) {
      $container = $config->get('az_blob_container_name');
    }
    return $container;
  }

  /**
   * Get Azure Blob storage account name.
   *
   * @return string|null
   */
  public function getAccountName(): ?string {
    $account_name = NULL;
    $config = $this->configFactory->get('az_blob_fs.settings');
    if ($config) {
      $account_name = $config->get('az_blob_account_name');
    }
    return $account_name;
  }

  /**
   * Get proxy client.
   *
   * @param array $data
   *
   * @return \Drupal\az_blob_fs\AzBlobRestProxyAlter
   */
  public function getAzBlobProxyClient(array $data = []): AzBlobRestProxyAlter {
    if (empty($config)) {
      $config = $this->configFactory->get('az_blob_fs.settings');
      if ($config) {
        $data = [
          'az_blob_account_name' => $config->get('az_blob_account_name'),
          'az_blob_account_key' => $config->get('az_blob_account_key'),
          'az_blob_local_emulator' => $config->get('az_blob_local_emulator'),
          'az_blob_local_ip' => $config->get('az_blob_local_ip'),
          'az_blob_local_port' => $config->get('az_blob_local_port'),
        ];
      }
    }
    $connectionString = "DefaultEndpointsProtocol=https;AccountName={$data['az_blob_account_name']};AccountKey={$data['az_blob_account_key']}";
    // Add emulator settings
    if (isset($data['az_blob_local_emulator']) && $data['az_blob_local_emulator']) {
      $connectionString .= ";BlobEndpoint=http://{$data['az_blob_local_ip']}:{$data['az_blob_local_port']}/{$data['az_blob_account_name']};";
    }
    return AzBlobRestProxyAlter::createBlobService($connectionString);
  }

}
