<?php

namespace Drupal\Tests\az_blob_fs\Functional;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Tests Azure Blog Storage configuration form.
 *
 * @group az_blob_fs
 */
class AzBlobFsConfigFormTest extends AzBlobFsTestBase {

  use StringTranslationTrait;

  /**
   * User with proper permissions for module configuration.
   *
   * @var \Drupal\user\Entity\User|false
   */
  protected $adminUser;

  /**
   * User with content access.
   *
   * @var \Drupal\user\Entity\User|false
   */
  protected $normalUser;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['az_blob_fs'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
  }

  /**
   * Test the Azure Blog Storage config form access.
   */
  public function testAzBlobFsConfigurationFormAccess() {

    $this->adminUser = $this->drupalCreateUser([
      'access administration pages',
      'administer site configuration',
      'administer az_blob_fs',
    ]);
    $this->drupalLogin($this->adminUser);

    // Access to the path
    $this->drupalGet('admin/config/media/az_blob_fs');

    // Check the response returned by Drupal.
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Test the Azure Blog Storage config form no access.
   */
  public function testAzBlobFsConfigurationFormNoAccess() {

    $this->normalUser = $this->drupalCreateUser(['access content']);
    $this->drupalLogin($this->normalUser);

    // Access to the path
    $this->drupalGet('admin/config/media/az_blob_fs');

    // Check the response returned by Drupal.
    $this->assertSession()->statusCodeEquals(403);

    // Logout as normal user and repeat the former cycle.
    $this->drupalLogout();
    $this->drupalGet('admin/config/media/az_blob_fs');
    $this->assertSession()->statusCodeEquals(403);
  }

  /**
   * Test the Azure Blog Storage config form.
   */
  public function testAzBlobFsConfigurationForm() {

    $this->adminUser = $this->drupalCreateUser([
      'access administration pages',
      'administer site configuration',
      'administer az_blob_fs',
    ]);
    $this->drupalLogin($this->adminUser);

    $edit['az_blob_account_name'] = $this->azBlobFsConfig['az_blob_account_name'];
    $edit['az_blob_account_key'] = $this->azBlobFsConfig['az_blob_account_key'];
    $edit['az_blob_container_name'] = $this->azBlobFsConfig['az_blob_container_name'];

    $this->drupalPostForm('admin/config/media/az_blob_fs', $edit, t('Save configuration'));
    $this->assertSession()->statusCodeEquals(200);

    $currentAccountKey = $this->config('az_blob_fs.settings')->get('az_blob_account_key');
    $this->assertEquals($this->azBlobFsConfig['az_blob_account_key'], $currentAccountKey, 'Account Key matches correctly.');
  }

}
